# Generated by roxygen2: do not edit by hand

export(run_app)
import(ggplot2)
import(shiny)
import(shinythemes)
importFrom(magrittr,"%>%")
importFrom(plotly,add_lines)
importFrom(plotly,add_markers)
importFrom(plotly,add_segments)
importFrom(plotly,layout)
importFrom(plotly,plot_ly)
importFrom(plotly,plotlyOutput)
importFrom(plotly,renderPlotly)
importFrom(stats,dbeta)
importFrom(stats,dgamma)
importFrom(stats,dlnorm)
importFrom(stats,qgamma)
importFrom(stats,qlnorm)
importFrom(stats,qnorm)
importFrom(stats,rgamma)
importFrom(stats,setNames)
importFrom(utils,read.csv)
importFrom(utils,write.csv)
